@@ -35,8 +35,13 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
     private Type type;
     private Type superClass;
     private Type[] implementz = new Type[0];
+    private TypeVariable[] typeParameters = TypeVariable.EMPTY_ARRAY; 
     private JavaClassContext context;
+    
+    //sourceless class can use this property
 	private JavaPackage javaPackage;
+	
+	private JavaSource source;
 
     public JavaClass() {
     }
@@ -182,7 +187,7 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
     }
 
     public void addMethod(JavaMethod meth) {
-        meth.setParent(this);
+        meth.setParentClass( this );
         methods.add(meth);
         methodsArray = null;
     }
@@ -195,35 +200,79 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
     public void setImplementz(Type[] implementz) {
         this.implementz = implementz;
     }
+    
+    public TypeVariable[] getTypeParameters()
+    {
+        return typeParameters;
+    }
+    
+    public void setTypeParameters( TypeVariable[] typeParameters )
+    {
+        this.typeParameters = typeParameters;
+    }
 
     public void addField(JavaField javaField) {
-        javaField.setParent(this);
+        javaField.setParentClass( this );
         fields.add(javaField);
         fieldsArray = null;
     }
     
+    /**
+     * Only used when constructing the model by hand / without source 
+     * 
+     * @param javaPackage
+     */
     public void setJavaPackage(JavaPackage javaPackage) {
     	this.javaPackage = javaPackage;
     }
 
+    public void setSource( JavaSource source )
+    {
+        this.source = source;
+    }
+    
     public JavaSource getParentSource() {
-        JavaClassParent parent = getParent();
-        return ((parent == null) ? null : parent.getParentSource());
+        return (getParentClass() != null ? getParentClass().getParentSource() : source);
+    }
+    
+    public JavaSource getSource()
+    {
+        return getParentSource();
     }
 
     public JavaPackage getPackage() {
-        return (getParentSource() != null ? getParentSource().getPackage() : javaPackage);
+        return getParentSource() != null ? getParentSource().getPackage() : javaPackage;
+    }
+    
+    public JavaClassParent getParent()
+    {
+        JavaClassParent result = getParentClass();
+        if (result == null) {
+            result = getParentSource();
+        }
+        return result;
+    }
+
+    /**
+     * If this class has a package, the packagename will be returned.
+     * Otherwise an empty String.
+     * 
+     * @return
+     */
+    public String getPackageName() {
+        JavaPackage javaPackage = getPackage();
+        return (javaPackage != null && javaPackage.getName() != null) ? javaPackage.getName() : "";
     }
 
     public String getFullyQualifiedName() {
-        return (getParent() != null ? (getParent().getClassNamePrefix()) : javaPackage != null ? (javaPackage.getName()+".") : "") + getName();
+        return (getParentClass() != null ? (getParentClass().getClassNamePrefix()) : getPackage() != null ? (getPackage().getName()+".") : "") + getName();
     }
 
     /**
      * @since 1.3
      */
     public boolean isInner() {
-        return getParent() instanceof JavaClass;
+        return getParentClass() != null;
     }
 
     public String resolveType(String typeName) {
@@ -320,6 +369,7 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
     }
 
     /**
+     * 
      * @param name           method name
      * @param parameterTypes parameter types or null if there are no parameters.
      * @return the matching method or null if no match is found.
@@ -328,7 +378,7 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
         JavaMethod[] methods = getMethods();
 
         for (int i = 0; i < methods.length; i++) {
-            if (methods[i].signatureMatches(name, parameterTypes)) {
+            if (methods[i].signatureMatches(name, parameterTypes, false)) {
                 return methods[i];
             }
         }
@@ -336,16 +386,56 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
         return null;
     }
 
+    /**
+     * 
+     * @param name
+     * @param parameterTypes
+     * @param superclasses
+     * @return
+     */
     public JavaMethod getMethodBySignature(String name, Type[] parameterTypes,
                                            boolean superclasses) {
+        return getMethodBySignature( name, parameterTypes, superclasses, false );
+    }
+    
+    /**
+     * 
+     * @param name
+     * @param parameterTypes
+     * @param superclasses
+     * @param varArg
+     * @return
+     */
+    public JavaMethod getMethodBySignature(String name, Type[] parameterTypes,
+                                           boolean superclasses, boolean varArg) {
         JavaMethod[] result = getMethodsBySignature(name, parameterTypes,
-                superclasses);
+                superclasses, varArg);
 
         return (result.length > 0) ? result[0] : null;
     }
-
+    
+    /**
+     * 
+     * @param name
+     * @param parameterTypes
+     * @param superclasses
+     * @return
+     */
     public JavaMethod[] getMethodsBySignature(String name,
                                               Type[] parameterTypes, boolean superclasses) {
+        return getMethodsBySignature( name, parameterTypes, superclasses, false );
+    }
+
+    /**
+     * 
+     * @param name
+     * @param parameterTypes
+     * @param superclasses
+     * @param varArg
+     * @return
+     */
+    public JavaMethod[] getMethodsBySignature(String name,
+                                              Type[] parameterTypes, boolean superclasses, boolean varArg) {
         List result = new ArrayList();
 
         JavaMethod methodInThisClass = getMethodBySignature(name, parameterTypes);
@@ -359,7 +449,7 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
 
             if (superclass != null) {
                 JavaMethod method = superclass.getMethodBySignature(name,
-                        parameterTypes, true);
+                        parameterTypes, true, varArg );
 
                 // todo: ideally we should check on package privacy too. oh well.
                 if ((method != null) && !method.isPrivate()) {
@@ -371,7 +461,7 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
 
             for (int i = 0; i < implementz.length; i++) {
                 JavaMethod method = implementz[i].getMethodBySignature(name,
-                        parameterTypes, true);
+                        parameterTypes, true, varArg );
 
                 if (method != null) {
                     result.add(method);
@@ -404,7 +494,7 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
     }
 
     public void addClass(JavaClass cls) {
-        cls.setParent(this);
+        cls.setParentClass( this );
         classes.add(cls);
         classesArray = null;
     }
