@@ -1,3 +1,4 @@
+
 package com.thoughtworks.qdox;
 
 import com.thoughtworks.qdox.model.*;
@@ -652,8 +653,8 @@ public class JavaDocBuilderTest extends MockObjectTestCase {
         builder.addSource(new StringReader(source));
         JavaClass x = builder.getClassByName("x");
         DocletTag tag = x.getTagByName("bar.baz");
-        assertEquals("foo=\"this is\\\nmultilined\"", tag.getValue());
-        assertEquals("this is\nmultilined", tag.getNamedParameter("foo"));
+        assertEquals("foo=\"this is\\\n      multilined\"", tag.getValue());
+        assertEquals("this is\n      multilined", tag.getNamedParameter("foo"));
     }
 
     public void testJiraQdox19() {
@@ -678,7 +679,7 @@ public class JavaDocBuilderTest extends MockObjectTestCase {
         String X = "" +
                 "/** @c x */" +
                 "class X {" +
-                "  /** " +
+                "  /** \n" +
                 "   * @m x \n" +
                 "   * @s f\n" +
                 "   */" +
@@ -847,7 +848,7 @@ public class JavaDocBuilderTest extends MockObjectTestCase {
         JavaField innerField = 
             builder.getClassByName("p2.B").getFieldByName("innerField");
         assertEquals(innerClass.asType(), innerField.getType());
-        assertEquals("p1.A$Inner", innerField.getType().getFullQualifiedName());
+        assertEquals("p1.A$Inner", innerField.getType().getFullyQualifiedName());
     }
 
     public void testJiraQdox71() {
@@ -1011,6 +1012,26 @@ public class JavaDocBuilderTest extends MockObjectTestCase {
         assertTrue("Public", modifiers.contains("public"));
     }
 
+    public void testMultipleFieldsWithJavaDoc() throws Exception {
+    	String sourceCode = "class Thing {\n" +
+    			" /** some doc */\n" +
+    			" int a = 1,\n" +
+    			" /** more doc */\n" +
+    			" b = 2,\n" +
+    			" /** etc */\n" +
+    			" c = 3; }";
+    	JavaDocBuilder builder = new JavaDocBuilder();
+    	builder.addSource(new StringReader(sourceCode));
+    	JavaClass javaClass = builder.getClasses()[0];
+    	JavaField fieldA = javaClass.getFieldByName("a");
+    	assertEquals("some doc", fieldA.getComment());
+    	JavaField fieldB = javaClass.getFields()[1];
+    	assertEquals("more doc", fieldB.getComment());
+    	JavaField fieldC = javaClass.getFields()[2];
+    	assertEquals("etc", fieldC.getComment());
+    }
+
+    
     public void testJiraQdox117() throws Exception {
     	JavaDocBuilder builder = new JavaDocBuilder();
         String sourceCode = "" +
@@ -1024,6 +1045,40 @@ public class JavaDocBuilderTest extends MockObjectTestCase {
         JavaMethod javaMethod = javaClass.getMethods()[0];
         assertEquals("\"test blah blah\"", javaMethod.getAnnotations()[0].getNamedParameter("description").toString());
     }
+    
+    public void testJiraQdox134() throws Exception {
+        String sourceCode = "/**\n" + 
+        		"*\n" + 
+        		"@myTag name=TestClass attrs=Something1,Something2,Something3\n" + 
+        		"*/\n" + 
+        		"public class TestClassImpl {\r\n" + 
+        		"}";
+        JavaDocBuilder builder = new JavaDocBuilder();
+        builder.addSource(new StringReader(sourceCode));
+        JavaClass jClass = builder.getClasses()[0];
+        assertEquals( Arrays.toString( new String[] {"name=TestClass","attrs=Something1,Something2,Something3"}), Arrays.toString(jClass.getTags()[0].getParameters()));
+        //assertTrue( Arrays.equals( new String[] {"name=TestClass","attrs=Something1,Something2,Something3"}, jClass.getTags()[0].getParameters() ));
+    }
+    
+    //for qdox-146
+    public void testWhitespaceCanBeRetainedInJavadoc() {
+        String sourceCode = ""
+                + "package com.acme.thing;\n"
+                + "\n"
+                + "/**\n"
+                + " * This class does something.\n"
+                + " *     chalala\n"
+                + " *         cha  **  lala\n"
+                + " **/\n"
+                + "public class AClassName {\n"
+                + "}";
+        JavaDocBuilder builder = new JavaDocBuilder();
+        builder.addSource(new StringReader(sourceCode));
+        JavaClass aClass = builder.getClassByName("com.acme.thing.AClassName");
+        assertEquals("This class does something.\n"
+                + "    chalala\n"
+                + "        cha  **  lala", aClass.getComment());
+    }
 
     //for qdox-152
     public void testExtendedClass() throws Exception {
@@ -1036,7 +1091,7 @@ public class JavaDocBuilderTest extends MockObjectTestCase {
     }
     
     //for QDox-154
-    public void todo_testImplicitJavadocCommentOrder() throws Exception {
+    public void testImplicitJavadocCommentOrder() throws Exception {
         String source = "" +
         		"public class Foo {\n" +
         		"    /**\n" + 
@@ -1065,8 +1120,7 @@ public class JavaDocBuilderTest extends MockObjectTestCase {
         assertEquals( "A Javadoc sample.", method1.getComment());
         assertEquals( "The size.", method1.getTagByName( "return" ).getValue());
         JavaMethod method2 = javaClass.getMethods()[1];
-        assertEquals( "The size.", method2.getTagByName( "return" ).getValue());
-        assertEquals( "A Javadoc sample.", method2.getComment());
+        assertEquals( "The size.\n\nA Javadoc sample.", method2.getTagByName( "return" ).getValue());
     }
 
     //for qdox-155
@@ -1099,4 +1153,105 @@ public class JavaDocBuilderTest extends MockObjectTestCase {
     	assertNotNull(javaClass.getAnnotations()[0].getNamedParameter("cascade"));
     } 
     
+    /**
+     * According to sun specs: Starting with Javadoc 1.4, the leading asterisks are optional
+     * @throws Exception
+     */
+    public void testJavadocWithoutStartingAsterisks() throws Exception {
+    	String source = "    /**\n" + 
+    			"     Some text\n" +
+    			"more text\n" +
+    			"\t and even more\n" +
+    			"     \n" + 
+    			"     @throws Exception\n" +
+    			"@deprecated" + 
+    			"     */\n" + 
+    			"public class Foo{}";
+    	JavaSource javaSource = builder.addSource(new StringReader(source));
+    	JavaClass javaClass = javaSource.getClasses()[0];
+    	assertEquals("Some text\nmore text\nand even more", javaClass.getComment());
+    	assertEquals("throws", javaClass.getTags()[0].getName());
+    	assertEquals("Exception", javaClass.getTags()[0].getValue());
+    	assertEquals("deprecated", javaClass.getTags()[1].getName());
+    }
+    
+    // for QDOX-189
+    public void testFinalAnnotationParam() {
+        JavaDocBuilder builder = new JavaDocBuilder();      
+        String source = "public final class WSEndpointReference {\n" +
+            "    public void writeTo(final @NotNull String localName, @NotNull XMLStreamWriter w) throws XMLStreamException {\n" +
+            "    }\n" +
+            "}";
+        builder.addSource(new StringReader(source));
+    }
+    
+    // for QDOX-190
+    public void testTwoCommentsBeforeEnumValue() {
+        JavaDocBuilder builder = new JavaDocBuilder();      
+        String source = 
+            "public enum Source {\n" +
+            "    /** comment 1 */    \n" +
+            "    /** comment 2 */\n" +
+            "    JDK1_2(\"1.2\");\n" +
+            "}\n";  
+        JavaSource src = builder.addSource(new StringReader(source));
+        assertEquals( "comment 2", src.getClasses()[0].getFieldByName( "JDK1_2" ).getComment() ); 
+    }
+
+    //for QDOX-191
+    public void testLeftShift() {
+        JavaDocBuilder builder = new JavaDocBuilder();
+        String source = 
+            "private static class Flags {\n" +
+            "   static final Flags LEFT_JUSTIFY = new Flags(1 << 0);\n" +
+            "}\n";
+        builder.addSource(new StringReader(source));
+    }
+    
+    public void testGenericConstructor() {
+        JavaDocBuilder builder = new JavaDocBuilder();
+        String source = 
+            "public class MXBeanSupport {\n" +
+            "  public <T> MXBeanSupport(T resource, Class<T> mxbeanInterface)\n" +
+            "    throws NotCompliantMBeanException {\n" +
+            " } \n" +
+            "}";        
+        builder.addSource(new StringReader(source));
+    }
+    
+    // for QDOX-195
+    public void testSharedPackageJavaClasses() {
+        String source1 = "@javax.xml.bind.annotation.XmlSchema(namespace = \"http://docs.oasis-open.org/wsn/br-2\")\n" +
+                "package com.foo;\n" +
+        		"public class Bar1 {}";
+        String source2 = "package com.foo;\n" +
+                "public class Bar2{}";
+        JavaSource javaSource1 = builder.addSource(new StringReader(source1));
+        JavaSource javaSource2 = builder.addSource(new StringReader(source2));
+        JavaPackage jPackage = builder.getPackageByName("com.foo");
+        assertEquals( 2, jPackage.getClasses().length );
+        assertEquals( 2, javaSource1.getPackage().getClasses().length );
+        assertEquals( 2, javaSource2.getPackage().getClasses().length );
+        assertNotSame( javaSource1.getPackage(), javaSource2.getPackage() );
+        assertEquals( 1, javaSource1.getPackage().getAnnotations().length );
+        assertEquals( 0, javaSource2.getPackage().getAnnotations().length );
+        assertEquals( 2, javaSource1.getPackage().getLineNumber() );
+        assertEquals( 1, javaSource2.getPackage().getLineNumber() );
+    }
+    
+    public void testSourceFolder() throws Exception {
+        JavaDocBuilder builder = new JavaDocBuilder();
+        builder.getClassLibrary().addSourceFolder( new File("target/test-source") );
+        String source = "package com.foo;\n" +
+        		"import com.blah.*;\n" +
+        		"public abstract class Me {\n" +
+        		" public abstract Thing getThing(); " +
+        		"}";
+        builder.addSource( new StringReader( source ) );
+        JavaClass clazz = builder.addSource( new StringReader( source ) ).getClasses()[0];
+        JavaClass thing = clazz.getMethods()[0].getReturns().getJavaClass();
+        assertEquals("com.blah.Thing", thing.getFullyQualifiedName());
+        assertNotNull(thing.getSource());
+    }
 }
+
