@@ -350,6 +350,7 @@ public class JavaClassTest extends TestCase {
 
         assertEquals("MyClass", cls.getName());
         assertEquals("com.thoughtworks.qdox", cls.getPackage().getName());
+        assertEquals("com.thoughtworks.qdox", cls.getPackageName());
         assertEquals("com.thoughtworks.qdox.MyClass",
                 cls.getFullyQualifiedName());
         assertTrue(cls.asType().isResolved());
@@ -375,9 +376,18 @@ public class JavaClassTest extends TestCase {
 
         assertEquals("Inner", inner.getName());
         assertEquals("foo.bar", inner.getPackage().getName());
+        assertEquals("foo.bar", inner.getPackageName());
         assertEquals("foo.bar.Outer$Inner",
                 inner.getFullyQualifiedName());
     }
+    
+    public void testDefaultPackageClass() {
+    	src.setPackage(null);
+    	cls.setName("DefaultPackageClass");
+    	
+    	assertEquals("", src.getClasses()[0].getPackageName());
+    	assertEquals("DefaultPackageClass", src.getClasses()[0].getFullyQualifiedName());
+    }
 
     public void testDefaultClassSuperclass() throws Exception {
         cls.setName("MyClass");
@@ -425,11 +435,8 @@ public class JavaClassTest extends TestCase {
         JavaMethod method = new JavaMethod();
         method.setReturns(new Type("void"));
         method.setName("doStuff");
-        JavaParameter[] parameters = {
-            new JavaParameter(new Type("int"), "x"),
-            new JavaParameter(new Type("double"), "y"),
-        };
-        method.setParameters(parameters);
+        method.addParameter( new JavaParameter(new Type("int"), "x") );
+        method.addParameter( new JavaParameter(new Type("double"), "y") );
         cls.addMethod(method);
 
         Type[] correctTypes = type(new String[]{"int", "double"});
@@ -477,11 +484,7 @@ public class JavaClassTest extends TestCase {
 
     public void testGetBeanPropertiesFindsSimpleProperties() throws Exception {
         JavaMethod setFooMethod = new JavaMethod("setFoo");
-        setFooMethod.setParameters(
-            new JavaParameter[] {
-                new JavaParameter(new Type("int"), "foo")
-            }
-        );
+        setFooMethod.addParameter(new JavaParameter(new Type("int"), "foo"));
         cls.addMethod(setFooMethod);
 
         JavaMethod getFooMethod = new JavaMethod(new Type("int"), "getFoo");
