@@ -171,9 +171,7 @@ public class ParserTest extends TestCase {
 
         // setup values
         setupLex(Parser.JAVADOCSTART);
-        setupLex(Parser.JAVADOCTOKEN, "This");
-        setupLex(Parser.JAVADOCTOKEN, "is");
-        setupLex(Parser.JAVADOCTOKEN, "great!");
+        setupLex(Parser.JAVADOCLINE, "This is great!");
         setupLex(Parser.JAVADOCEND);
         setupLex(0);
 
@@ -194,8 +192,7 @@ public class ParserTest extends TestCase {
         // setup values
         setupLex(Parser.JAVADOCSTART);
         setupLex(Parser.JAVADOCTAG, "@This");
-        setupLex(Parser.JAVADOCTOKEN, "is");
-        setupLex(Parser.JAVADOCTOKEN, "great!");
+        setupLex(Parser.JAVADOCLINE, "is great!");
         setupLex(Parser.JAVADOCEND);
         setupLex(0);
 
@@ -236,9 +233,7 @@ public class ParserTest extends TestCase {
         // setup values
         setupLex(Parser.JAVADOCSTART);
         setupLex(Parser.JAVADOCTAG, "@This");
-        setupLex(Parser.JAVADOCTOKEN, "is");
-        setupLex(Parser.JAVADOCTOKEN, "great!");
-        setupLex(Parser.JAVADOCTOKEN, "Mmmkay.");
+        setupLex(Parser.JAVADOCLINE, "is great! Mmmkay.");
         setupLex(Parser.JAVADOCEND);
         setupLex(0);
 
@@ -262,10 +257,9 @@ public class ParserTest extends TestCase {
         // setup values
         setupLex(Parser.JAVADOCSTART);
         setupLex(Parser.JAVADOCTAG, "@This");
-        setupLex(Parser.JAVADOCTOKEN, "is");
-        setupLex(Parser.JAVADOCTOKEN, "great!");
+        setupLex(Parser.JAVADOCLINE, "is great!");
         setupLex(Parser.JAVADOCTAG, "@mock");
-        setupLex(Parser.JAVADOCTOKEN, "generate");
+        setupLex(Parser.JAVADOCLINE, "generate");
         setupLex(Parser.JAVADOCEND);
         setupLex(0);
 
@@ -287,16 +281,11 @@ public class ParserTest extends TestCase {
 
         // setup values
         setupLex(Parser.JAVADOCSTART);
-        setupLex(Parser.JAVADOCTOKEN, "Welcome!");
-        setupLex(Parser.JAVADOCTOKEN, "Here");
-        setupLex(Parser.JAVADOCTOKEN, "is");
-        setupLex(Parser.JAVADOCTOKEN, "my");
-        setupLex(Parser.JAVADOCTOKEN, "class.");
+        setupLex(Parser.JAVADOCLINE, "Welcome! Here is my class.");
         setupLex(Parser.JAVADOCTAG, "@This");
-        setupLex(Parser.JAVADOCTOKEN, "is");
-        setupLex(Parser.JAVADOCTOKEN, "great!");
+        setupLex(Parser.JAVADOCLINE, "is great!");
         setupLex(Parser.JAVADOCTAG, "@mock");
-        setupLex(Parser.JAVADOCTOKEN, "generate");
+        setupLex(Parser.JAVADOCLINE, "generate");
         setupLex(Parser.JAVADOCEND);
         setupLex(0);
 
@@ -789,11 +778,11 @@ public class ParserTest extends TestCase {
 
         // setup values
         setupLex(Parser.JAVADOCSTART);
-        setupLex(Parser.JAVADOCTOKEN, "javadoc1");
+        setupLex(Parser.JAVADOCLINE, "javadoc1");
         setupLex(Parser.JAVADOCEND);
 
         setupLex(Parser.JAVADOCSTART);
-        setupLex(Parser.JAVADOCTOKEN, "javadoc2");
+        setupLex(Parser.JAVADOCLINE, "javadoc2");
         setupLex(Parser.JAVADOCEND);
 
         setupLex(Parser.PACKAGE);
@@ -801,11 +790,11 @@ public class ParserTest extends TestCase {
         setupLex(Parser.SEMI);
 
         setupLex(Parser.JAVADOCSTART);
-        setupLex(Parser.JAVADOCTOKEN, "javadoc3");
+        setupLex(Parser.JAVADOCLINE, "javadoc3");
         setupLex(Parser.JAVADOCEND);
 
         setupLex(Parser.JAVADOCSTART);
-        setupLex(Parser.JAVADOCTOKEN, "javadoc4");
+        setupLex(Parser.JAVADOCLINE, "javadoc4");
         setupLex(Parser.JAVADOCEND);
 
         setupLex(Parser.IMPORT);
@@ -815,11 +804,11 @@ public class ParserTest extends TestCase {
         setupLex(Parser.SEMI);
 
         setupLex(Parser.JAVADOCSTART);
-        setupLex(Parser.JAVADOCTOKEN, "javadoc5");
+        setupLex(Parser.JAVADOCLINE, "javadoc5");
         setupLex(Parser.JAVADOCEND);
 
         setupLex(Parser.JAVADOCSTART);
-        setupLex(Parser.JAVADOCTOKEN, "javadoc6");
+        setupLex(Parser.JAVADOCLINE, "javadoc6");
         setupLex(Parser.JAVADOCEND);
 
         setupLex(Parser.IMPORT);
@@ -829,11 +818,11 @@ public class ParserTest extends TestCase {
         setupLex(Parser.SEMI);
 
         setupLex(Parser.JAVADOCSTART);
-        setupLex(Parser.JAVADOCTOKEN, "javadoc7");
+        setupLex(Parser.JAVADOCLINE, "javadoc7");
         setupLex(Parser.JAVADOCEND);
 
         setupLex(Parser.JAVADOCSTART);
-        setupLex(Parser.JAVADOCTOKEN, "javadoc8");
+        setupLex(Parser.JAVADOCLINE, "javadoc8");
         setupLex(Parser.JAVADOCEND);
 
         setupLex(Parser.PUBLIC);
@@ -843,11 +832,11 @@ public class ParserTest extends TestCase {
         setupLex(Parser.BRACECLOSE);
 
         setupLex(Parser.JAVADOCSTART);
-        setupLex(Parser.JAVADOCTOKEN, "javadoc9");
+        setupLex(Parser.JAVADOCLINE, "javadoc9");
         setupLex(Parser.JAVADOCEND);
 
         setupLex(Parser.JAVADOCSTART);
-        setupLex(Parser.JAVADOCTOKEN, "javadoc10");
+        setupLex(Parser.JAVADOCLINE, "javadoc10");
         setupLex(Parser.JAVADOCEND);
 
         setupLex(0);
@@ -1078,8 +1067,9 @@ public class ParserTest extends TestCase {
         FieldDef p1 = new FieldDef();
         p1.name = "numberOfTimes";
         p1.type = new TypeDef("int");
-        mth.params.add(p1);
+        
         builder.addExpectedAddMethodValues(mth);
+        builder.addExpectedAddParameterValues( p1 );
 
         // execute
         Parser parser = new Parser(lexer, builder);
@@ -1118,8 +1108,9 @@ public class ParserTest extends TestCase {
         FieldDef p1 = new FieldDef();
         p1.name = "numberOfTimes";
         p1.type = new TypeDef("java.lang.String");
-        mth.params.add(p1);
+
         builder.addExpectedAddMethodValues(mth);
+        builder.addExpectedAddParameterValues( p1 );
 
         // execute
         Parser parser = new Parser(lexer, builder);
@@ -1157,12 +1148,12 @@ public class ParserTest extends TestCase {
         FieldDef p1 = new FieldDef();
         p1.name = "numberOfTimes";
         p1.type = new TypeDef("int");
-        mth.params.add(p1);
         FieldDef p2 = new FieldDef();
         p2.name = "name";
         p2.type = new TypeDef("String");
-        mth.params.add(p2);
         builder.addExpectedAddMethodValues(mth);
+        builder.addExpectedAddParameterValues( p1 );
+        builder.addExpectedAddParameterValues( p2 );
 
         // execute
         Parser parser = new Parser(lexer, builder);
@@ -1203,16 +1194,16 @@ public class ParserTest extends TestCase {
         FieldDef p1 = new FieldDef();
         p1.name = "numberOfTimes";
         p1.type = new TypeDef("int");
-        mth.params.add(p1);
         FieldDef p2 = new FieldDef();
         p2.name = "name";
         p2.type = new TypeDef("String");
-        mth.params.add(p2);
         FieldDef p3 = new FieldDef();
         p3.name = "x";
         p3.type = new TypeDef("boolean");
-        mth.params.add(p3);
         builder.addExpectedAddMethodValues(mth);
+        builder.addExpectedAddParameterValues( p1 );
+        builder.addExpectedAddParameterValues( p2 );
+        builder.addExpectedAddParameterValues( p3 );
 
         // execute
         Parser parser = new Parser(lexer, builder);
@@ -1251,9 +1242,9 @@ public class ParserTest extends TestCase {
         p1.type = new TypeDef("int");
         p1.modifiers.add("final");
         p1.modifiers.add("volatile");
-        mth.params.add(p1);
         builder.addExpectedAddMethodValues(mth);
-
+        builder.addExpectedAddParameterValues( p1 );
+        
         // execute
         Parser parser = new Parser(lexer, builder);
         parser.parse();
@@ -1506,9 +1497,9 @@ public class ParserTest extends TestCase {
         FieldDef p1 = new FieldDef();
         p1.name = "count";
         p1.type = new TypeDef("int");
-        mth.params.add(p1);
 
         builder.addExpectedAddMethodValues(mth);
+        builder.addExpectedAddParameterValues( p1 );
 
         // execute
         Parser parser = new Parser(lexer, builder);
@@ -1551,14 +1542,14 @@ public class ParserTest extends TestCase {
         FieldDef p1 = new FieldDef();
         p1.name = "count";
         p1.type = new TypeDef("int");
-        mth.params.add(p1);
         FieldDef p2 = new FieldDef();
         p2.name = "thingy";
         p2.type = new TypeDef("java.lang.String");
-        mth.params.add(p2);
 
         builder.addExpectedAddMethodValues(mth);
-
+        builder.addExpectedAddParameterValues( p1 );
+        builder.addExpectedAddParameterValues( p2 );
+        
         // execute
         Parser parser = new Parser(lexer, builder);
         parser.parse();
@@ -2290,9 +2281,9 @@ public class ParserTest extends TestCase {
         p1.name = "p1";
         p1.type = new TypeDef("int");
         p1.dimensions = 0;
-        mth.params.add(p1);
 
         builder.addExpectedAddMethodValues(mth);
+        builder.addExpectedAddParameterValues( p1 );
 
         // execute
         Parser parser = new Parser(lexer, builder);
@@ -2333,9 +2324,9 @@ public class ParserTest extends TestCase {
         p1.name = "p1";
         p1.type = new TypeDef("int");
         p1.dimensions = 1;
-        mth.params.add(p1);
 
         builder.addExpectedAddMethodValues(mth);
+        builder.addExpectedAddParameterValues( p1 );
 
         // execute
         Parser parser = new Parser(lexer, builder);
@@ -2380,9 +2371,9 @@ public class ParserTest extends TestCase {
         p1.name = "p1";
         p1.type = new TypeDef("int");
         p1.dimensions = 2;
-        mth.params.add(p1);
 
         builder.addExpectedAddMethodValues(mth);
+        builder.addExpectedAddParameterValues( p1 );
 
         // execute
         Parser parser = new Parser(lexer, builder);
@@ -2422,9 +2413,9 @@ public class ParserTest extends TestCase {
         p1.type = new TypeDef("int");
         p1.dimensions = 0;
         p1.isVarArgs = true;
-        mth.params.add(p1);
 
         builder.addExpectedAddMethodValues(mth);
+        builder.addExpectedAddParameterValues(p1);
 
         // execute
         Parser parser = new Parser(lexer, builder);
